
local Assets =
{
	Asset("ANIM", "anim/firstaidkit.zip"), -- a standard asset
    Asset("ATLAS", "images/inventoryimages/firstaidkit.xml"),    -- a custom asset, found in the mod folder
}

TUNING.FIRSTAIDKIT_FUEL = 800
TUNING.FIRSTAIDKIT_VORDER = -20
TUNING.FIRSTAIDKIT_HEALVAL = 20


-- this function is called by owner
local function healing(owner)
    -- print("First Aid Kit healing(), owner is "..owner.prefab)
    if owner.components.health then
        local health = owner.components.health
        if (health.currenthealth - health:GetMaxWithPenalty()) < TUNING.FIRSTAIDKIT_VORDER then
            if owner.components.inventory then
                local inventory = owner.components.inventory
                local faKit = inventory:FindItem(function(i) return i.prefab == "firstaidkit" end)
                if faKit then
                    -- print("\tfirstaidkit is found")
                    faKit.SoundEmitter:PlaySound("dontstarve/HUD/repair_clothing")
                    faKit.components.fueled:DoDelta(-TUNING.FIRSTAIDKIT_HEALVAL)
                    health:DoDelta(TUNING.FIRSTAIDKIT_HEALVAL)
                else
                    -- print("\tfirstaidkit is not found!")
                end
            end
        end
    end
end


local function onPickup(inst, owner)
	local o = inst.components.inventoryitem:GetGrandOwner()
	if o then
		owner = o
	end
    -- print("First Aid Kit onPickup(), owner is "..owner.prefab)

    if owner.components.health then
        local health = owner.components.health
        if not health.firstaidkit_fn01 then
            -- print("First Aid Kit onPickup(), overwrite the owner.components.health.DoDelta")
            health.firstaidkit_fn01 = health.DoDelta
            function health:DoDelta(amount, overtime, cause, ignore_invincible, afflicter, ignore_absorb)
                health:firstaidkit_fn01(amount, overtime, cause, ignore_invincible, afflicter, ignore_absorb)
                healing(owner)
            end
        end
    end
end


local function fn(Sim)
	local inst = CreateEntity()
	inst.entity:AddTransform()
	inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    inst.entity:AddNetwork()
    MakeInventoryPhysics(inst)
    
    inst.AnimState:SetBank("myprefab")
    inst.AnimState:SetBuild("firstaidkit")
    inst.AnimState:PlayAnimation("idle")

    if not TheWorld.ismastersim then   
      return inst  
    end   
    
    inst.entity:SetPristine()     

    inst.owner = nil
    inst:AddComponent("inventoryitem")
	inst.components.inventoryitem.atlasname = "images/inventoryimages/firstaidkit.xml"
    inst.components.inventoryitem:SetOnPutInInventoryFn(onPickup)

	inst:AddComponent("inspectable")

    inst:AddComponent("fueled")
    inst.components.fueled:InitializeFuelLevel(TUNING.FIRSTAIDKIT_FUEL)
    inst.components.fueled:SetDepletedFn(inst.Remove)

    MakeSmallBurnable(inst, TUNING.TINY_BURNTIME)
    MakeSmallPropagator(inst)
    MakeHauntableLaunch(inst) 

    return inst
end



STRINGS.NAMES.FIRSTAIDKIT = "First Aid Kit"
STRINGS.CHARACTERS.GENERIC.DESCRIBE.FIRSTAIDKIT = "Healing HP automatically."

return Prefab( "common/inventory/firstaidkit", fn, Assets)
